@@ -37,7 +37,6 @@
     RegExpPrototypeTest,
     Symbol,
     SymbolFor,
-    SymbolToStringTag,
     TypeError,
   } = window.__bootstrap.primordials;
 
@@ -102,37 +101,33 @@
       type: response.type,
       body,
       headerList,
-      url() {
-        if (this.urlList.length == 0) return null;
-        return this.urlList[this.urlList.length - 1];
-      },
       urlList,
       status: response.status,
       statusMessage: response.statusMessage,
       aborted: response.aborted,
+      url() {
+        if (this.urlList.length == 0) return null;
+        return this.urlList[this.urlList.length - 1];
+      },
     };
   }
 
-  const defaultInnerResponse = {
-    type: "default",
-    body: null,
-    aborted: false,
-    url() {
-      if (this.urlList.length == 0) return null;
-      return this.urlList[this.urlList.length - 1];
-    },
-  };
-
   /**
    * @returns {InnerResponse}
    */
   function newInnerResponse(status = 200, statusMessage = "") {
     return {
+      type: "default",
+      body: null,
       headerList: [],
       urlList: [],
       status,
       statusMessage,
-      ...defaultInnerResponse,
+      aborted: false,
+      url() {
+        if (this.urlList.length == 0) return null;
+        return this.urlList[this.urlList.length - 1];
+      },
     };
   }
 
@@ -157,10 +152,6 @@
   }
 
   class Response {
-    /** @type {InnerResponse} */
-    [_response];
-    /** @type {Headers} */
-    [_headers];
     get [_mimeType]() {
       let charset = null;
       let essence = null;
@@ -254,7 +245,7 @@
      */
     constructor(body = null, init = {}) {
       const prefix = "Failed to construct 'Response'";
-      body = webidl.converters["BodyInit?"](body, {
+      body = webidl.converters["BodyInit_DOMString?"](body, {
         prefix,
         context: "Argument 1",
       });
@@ -275,7 +266,9 @@
 
       this[webidl.brand] = webidl.brand;
       const response = newInnerResponse(init.status, init.statusText);
+      /** @type {InnerResponse} */
       this[_response] = response;
+      /** @type {Headers} */
       this[_headers] = headersFromHeaderList(response.headerList, "response");
       if (init.headers !== undefined) {
         fillHeaders(this[_headers], init.headers);
@@ -373,10 +366,6 @@
       return second;
     }
 
-    get [SymbolToStringTag]() {
-      return "Response";
-    }
-
     [SymbolFor("Deno.customInspect")](inspect) {
       return inspect(consoleInternal.createFilteredInspectProxy({
         object: this,
